==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/MarkRelationType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Change the marked state of the selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for MarkRelationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MarkRelationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/extraction/info}BaseRelationType">
 *       <attribute name="marked" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MarkRelationType")
public class MarkRelationType
    extends BaseRelationType
{

    @XmlAttribute(name = "marked")
    protected Boolean marked;

    /**
     * Gets the value of the marked property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMarked() {
        if (marked == null) {
            return false;
        } else {
            return marked;
        }
    }

    /**
     * Sets the value of the marked property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setMarked(boolean value) {
        this.marked = value;
    }

    public boolean isSetMarked() {
        return (this.marked!= null);
    }

    public void unsetMarked() {
        this.marked = null;
    }

}

==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/extraction/info/MarkRelationType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Change the marked state of the selected annotation.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for MarkRelationType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="MarkRelationType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/extraction/info}BaseRelationType">
 *       <attribute name="marked" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MarkRelationType")
public class MarkRelationType
    extends BaseRelationType
{

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If this is set to true, the selected annotation has been marked, otherwise it has been unmarked.&lt;/p&gt;
     * </pre>
     * 
     */
    @XmlAttribute(name = "marked")
    protected Boolean marked;

    /**
     * <pre>
     * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns="http://schema.webpdf.de/1.0/extraction/info" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;If this is set to true, the selected annotation has been marked, otherwise it has been unmarked.&lt;/p&gt;
     * </pre>
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isMarked() {
        if (marked == null) {
            return false;
        } else {
            return marked;
        }
    }

    /**
     * Sets the value of the marked property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     * @see #isMarked()
     */
    public void setMarked(boolean value) {
        this.marked = value;
    }

    public boolean isSetMarked() {
        return (this.marked!= null);
    }

    public void unsetMarked() {
        this.marked = null;
    }

}
